package cn.com.infosec.crypto.params;

import cn.com.infosec.crypto.KeyGenerationParameters;
import java.math.BigInteger;
import java.security.SecureRandom;

public class RSAKeyGenerationParameters extends KeyGenerationParameters {
   private BigInteger publicExponent;
   private int certainty;

   public RSAKeyGenerationParameters(BigInteger publicExponent, SecureRandom random, int strength, int certainty) {
      super(random, strength);
      if (strength >= 12) {
         if (publicExponent.testBit(0)) {
            this.publicExponent = publicExponent;
            this.certainty = certainty;
         } else {
            throw new IllegalArgumentException("public exponent cannot be even");
         }
      } else {
         throw new IllegalArgumentException("key strength too small");
      }
   }

   public BigInteger getPublicExponent() {
      return this.publicExponent;
   }

   public int getCertainty() {
      return this.certainty;
   }
}
